Monty Python's Flying Circus: Just the Words - Episode 19

# Episode Nineteen

'It's a Living'
The time on BBC 1
School prize-giving
'if' - a film by Mr Dibley
'Rear Window' - a film by Mr Dibley
'Finian's Rainbow' (starring the man from the off-license)
Foreign Secretary
Dung
Dead Indian
Timmy Williams interview
Raymond Luxury Yacht interview
Registry office
Election Night Special (Silly and Sensible Parties)

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Quiz show set-up. Two contestants either side, compère in the middle. On the back wall in large letters it says 'It's a Living'. Music plays brightly. Track quickly into compère, losing contestants, as he starts his quick spiel. CAPTION: 'IT'S A LIVING'
Compère | Hello, good evening, and welcome to 'It's A Living'. The rules are very simple: each week we get a large fee; at the end of that week we get another large fee; if there's been no interruption at the end of the year we get a repeat fee which can be added on for tax purposes to the previous year or the following year if there's no new series. Every contestant, in addition to getting a large fee is entitled to three drinks at the BBC or if the show is over, seven drinks - unless he is an MP, in which case he can have seven drinks before the show, or a bishop only three drinks in toto. The winners will receive an additional fee, a prize which they can flog back and a special fee for a guest appearance on 'Late Night Line Up'. Well, those are the rules, that's the game, we'll be back again same time next week. Till then. Bye-bye.
| Cut to BBC world symbol.
Voice Over | Well, it's five past nine and nearly time for six past nine. On BBC 2 now it'll shortly be six and a half minutes past nine. Later on this evening it'll be ten o'clock and at 10.30 we'll be joining BBC 2 in time for 10.33, and don't forget tomorrow when it'll be 9.20. Those of you who missed 8.45 on Friday will be able to see it again this Friday at a quarter to nine. Now here is a time check. It's six and a half minutes to the big green thing.
Second Voice Over | You're a loony.
Voice Over | I get so bored. I get so bloody bored.
| ANIMATION: for a minute or two strange things happen on animation until suddenly we find ourselves into the animated title sequence. Cut to the announcer in a silly location, sitting at his desk as usual.
Announcer | You probably noticed that I didn't say 'and now for something completely different' just now. This is simply because I am unable to appear in the show this week. (looks closely at script, puzzled) Sorry to interrupt you.
| Cut to a man holding his mouth open to show the camera his teeth.
Man | I'm terribly sorry to interrupt but my tooth's hurting, just around here.
Voice | Get off.
Man | Oh, sorry.
| Cut to pompous moustached stockbroker type.
Nabarro | I'm not sorry to interrupt - I'll interrupt anything if it gets people looking in my direction - like at my old school where, by a coincidence, the annual prize giving is going on at this very moment.
| There is a ripple effect, and a muted trumpet plays a corny segue sequence. We mix through to the trumpeter at a school prize giving. On the stage of the school hall there is a long table behind which are sitting several distinguished people. A bishop in a grey suit and purple stock and dog collar gets up.
Bishop | My Lord Mayor, Lady Mayoress, it gives me very great pleasure to return to my old school, to present the prizes in this centenary year. This school takes very justifiable pride in its fine record of... aaaaagh!
| Hands pull him down behind the table. Fighting, punching, struggle, grunts etc. No reaction at all from the distinguished guests. The bishop's head reappears for a moment.
Bishop | ... scholarship and sporting achievement in all... aaaagh!
| He disappears again. More noises. Up comes another bishop dressed identically.
Second Bishop | I'm, I'm afraid there's been a mistake. The man who has been speaking to you is an impostor. He is not in fact the Bishop of East Anglia, but a man wanted by the police. I am the Bishop of East Anglia and anyone who doesn't believe me can look me up in the book. Now then, the first prize is this beautiful silver cup, which has been won by me. (he puts the silver cup into a sack) Next we come to the Fairfax Atkinson Trophy for outstanding achievement in the field of Applied Mathematics. Well, there was no-one this year who reached the required standard so it goes in my sack. And by an old rule of the school all the other silver trophies also go in my sack ... aaagh!
| He is dragged down by an unseen hand. More sounds of fighting, noisier than before even. A Chinaman in Mao jacket and cap appears.
Chinaman | Velly solly for hold-up ... no ploblem now ... me are Bishop of East Anglia, now piesent plizes ... Eyes down for first plize ... The Fyffe-Chulmleigh Spoon for Latin Elegaics... 'goes to ... People's Republic of China! Aaaagh!
| The Chinaman is dragged down beneath the table as were the others. Again sound of struggle, thumps etc. A plainclothes policeman stands up.
Detective | Good evening, everybody. My name's Bradshaw - Inspector Elizabeth Bradshaw, of the Special Branch Speech Day Squad, but I'd like you to think of me as the Bishop of East Anglia, and I'd like to present the first prize, the Grimwade Gynn Trophy to...
| A shot. He leaps backwards. Sound of machine guns and exploding shells. Two men in army uniform with camouflage sticking out of tin helmets rush up to the table and exchange fire. They have a huge bazooka which they fire from time to time.
Soldier | (appearing from beneath the table, shouting above the din of the battle) Lord Mayor, Lady Mayoress, ladies, gentlemen and boys. Please do not panic. Please keep your heads right down now, and at the back please keep your heads right down. Do not panic, don't look round - this building is surrounded. There is nothing to worry about. I am the Bishop of East Anglia. Now the first prize is the Granville Cup for French Unseen Translation ... (explosion and smoke, debris over the stage) and it goes to Forbes Minor... Forbes Minor ... right, give him covering fire ... (explosion) Come on Forbes. Come on boy. Come and get it. Keep down. (a wretched schoolboy appears on the stage keeping his head down) Well done... (he manages to get the cup but as he stands to shake hands he is shot) Oh... bad luck! The next prize...
| Mix through to a picture on a TV monitor and pull out from monitor to reveal a studio set as for a late-night discussion programme.
Interviewer | Mr L.F. Dibley's latest film 'if'. (he turns to Dibley) Mr Dibley, some people have drawn comparisons between your film, 'if', which ends with a gun battle at a public school, and Mr Lindsay Anderson's film, 'if', which ends with a gun battle at a public school.
Dibley | Oh yes, well, I mean, there were some people who said my film '2001 - A Space Odyssey', was similar to Stanley Kubrick's. I mean, that's the sort of petty critical niggling that's dogged my career. It makes me sick. I mean, as soon as I'd made 'Midnight Cowboy' with the vicar as Ratso Rizzo, John Schlesinger rushes out his version, and gets it premiered while mine's still at the chemist's.
Interviewer | Well, we have with us tonight one of your films, 'Rear Window', which was to become such a success for Alfred Hitchcock a few weeks later. Now this is a silent film, so perhaps you could talk us through it...
| Cut to a dim, shaky 8mm shot of a window. It is open. After a few seconds a man appears and looks out. He then performs over-exaggerated horror and points, looking at camera. Then he disappears and then he reappears.
Dibley | Yes, well, let's see now ... there's the rear window. There's the man looking out of the window. He sees the murder. The murderer's come into the room to kill him, but he's outwitted him and he's all right. The End. I mean, Alfred Hitchcock, who's supposed to be so bloody wonderful, padded that out to one and a half hours ... lost all the tension ... just because he had bloody Grace Kelly he made £3 million more than I did. Mind you, at least she can act a bit, I could have done with her in 'Finian's Rainbow' ... The man from the off-licence was terrible ... a real failure that was - ten seconds of solid boredom.
| Cut to shaky titles: Mr Dibley's 'Finian's Rainbow starring the man from the off-licence'. Cut to the man from the off-licence standing by a tennis-court. He wears a dress and appears to be trying to say something - he has forgotten his words. He does an unconvincing little dance. CAPTION: 'THE END'
Dibley | Bloody terrible.
Interviewer | Mr L. F. Dibley's 'Finian's Rainbow'. And now over to me. (close-up of interviewer) Exclusively on the programme today we have the Foreign Secretary, who has just returned from the bitter fighting in the Gulf of Amman. He's going to tell us about canoeing.
| On the bank of a river seen from the other side. There is a canoe on the bank a man in a pinstripe suit stands beside it. SUPERIMPOSEN CAPTION: 'THE FOREIGN SECRETARY' He gives a little cough and gets in. Two Arabs run in from other side of frame, lift up the canoe and throw it and the Foreign Secretary into the water. Cut back to the interviewer.
Interviewer | That gives you just some idea of what's going on out there. Today saw the long-awaited publication of the Portman Committee's Report on Industrial Reorganization...
| CAPTION: 'SOMETHING SILLY'S GOING TO HAPPEN'
Interviewer | It's taken five years to prepare and it's bound to have an enormous impact on the future of industrial relations in this country. In the studio tonight Lord Porlman, Chairman of the Committee, Sir Charles Avery, Employers' Reorganization Council, and Ray Millichope, leader of the Allied Technicians' Union. And they're going to make a human pyramid.
| Three men in shorts run on to accompaniment of tinkly music and form a pyramid As they complete it we cut to film of Vatican crowds and dub on enormous ovation.
Interviewer | Bra... vo. Now the President of the Board of Trade...
| Cut back to the same river bank shot from across the river. The President of the Board of Trade in pinstripes is standing beside a hamper. He smiles and gets in, and lowers the lid. Once again two Arabs run in from either side and throw it in. All these sequences are speeded up.
Interviewer | Now here's the Vice-Chairman of ICI.
| Cut back to same river bank. A head looking out of the hamper. It disappears as two Arabs run in and toss it in.
Interviewer | Well, so much for politics and the problems of Britain's industrial reorganization. Now we turn to the lighter subject of sport, and Reg Harris, the former world cycling sprint champion, talks to us about the psychological problems of big race preparation. (Reg and his bike are thrown in the river by the Arabs) And now the world of song - Anne Zeigler and Webster Booth. (two hampers thrown in river by four Arabs) Well, all good things must come to an end, and that's all for this week. But to close our programme, Dame Irene Stoat, who celebrates her eighty-fifth birthday this month, reads one of her most famous poems.
| Cut to the river bank. An old lady is standing beside it, but this time on the bank of the river nearest the camera. On the other bank we see the Arabs run into shot, realize they've been foiled and leap up and down in anger.
Dame Irene | Who shall declare this good, that ill When good and ill so intertwine But to fulfil the vast design of an omniscient will. When seeming again but turns to loss When earthly treasure proves but dross And what seems lost but turns again To high eternal gain.
| The Arabs run out of vision. Suddenly, from right beside the camera, with a bloodcurdling scream a Samurai warrior with drawn sword leaps upon her and hurls her backwards into the water. The warrior then strikes up a fierce heroic pose for the camera. SUPERIMPOSE CAPTION: 'NEWHAVEN - LE HAVRE. GETAWAY TO THE CONTINENT' Cut to a smart dinner party. There are two couples in evening dress at the table. Candles burning on the polished wood, a fire burning in the grate. Muted music and sophisticated lighting.
Hostess (Rita Davies) | We had the most marvelous holiday. It was absolutely fantastic.
Host | Absolutely wonderful.
Hostess | Michael, you tell them about it.
Host | No, darling, you tell them.
Hostess | You do it so much better.
| The doorbell rings.
Host | Excuse me a moment.
| The host goes and answers the door of the flat, which opens straight into the dining room. Standing at the door is a large grubby man carrying a tub on his shoulder. There are flies buzzing around him. He walks straight in.
Man | Dung, sir.
Host | What?
Man | We've got your dung.
Host | What dung?
Man | Your dung. Three hundredweight of heavy droppings. Where do you want it? (he looks round for a likely place)
Host | I didn't order any dung.
Man | Yes you did, sir. You ordered it through the Book of the Month Club.
Host | Book of the Month Club?
Man | That's right, sir. You get 'Gone with the Wind', 'Les Miserables' by Victor Hugo, 'The French Lieutenant's Woman' and with every third book you get dung.
Host | I didn't know that when I signed the form.
Man | Well, no, no. It wasn't on the form - they found it wasn't good for business. Anyway, we've got three hundredweight of dung in the van. Where do you want it?
Host | Well, I don't think we do. We've no garden.
Man | Well, it'll all fit in here - it's top-class excrement.
Host | You can't put it in here, we've having a dinner party!
Man | 'Salright. I'll put it on the telly.
| He brings it into the dining room. The guests ignore him.
Host | Darling... there's a man here with our Book of the Month Club dung.
Hostess | We've no room, dear.
Man | Well, how many rooms have you got, then?
Host | Well, there's only this room, the bedroom, a spare room.
Man | Oh well, I'll tell you what, move everything into the main bedroom, then you can use the spare room as a dung room.
| The doorbell goes and there standing at the door which hasn't been closed is a gas board official with a dead Indian over his shoulders.
Host | Yes.
Gas Man | Dead Indian.
Host | What?
Gas Man | Have you recently bought a new cooker, sir?
Host | Yes.
Gas Man | Ah well, this is your free dead Indian, as advertised...
Host | I didn't see that in the adverts...
Gas Man | No, it's in the very small print, you see, sir, so as not to affect the sales.
Host | We've no room.
Man | That's all right - you can put the dead Indian in the spare room on top of the dung.
Dead Indian | Me ... heap dizzy.
Host | He's not dead!
Gas Man | Oh well, that's probably a faulty cooker.
| The phone rings. The wife goes to answer it.
Man | Have you, er... you read and enjoyed 'The French Lieutenant's Woman', then?
Host | No.
Man | No... still, it's worth it for the dung, isn't it?
Hostess | Darling, it's the Milk Marketing Board. For every two cartons of single cream we get the M4 motorway.
| Cut to host and hostess standing bewildered in the middle of a motorway. Beside them is a steaming pile of dung, and a dead Indian. They look round in amazement. A police car roars up to them and two policemen leap out.
Policeman | Are you Mr and Mrs P. Forbes of 7, the Studios, Elstree?
Host | Yes.
Policeman | Right, well, get in the car. We've won you in a police raffle.
| Speeded up, they are bundled into the car. Cut to inspector.
Inspector | Yes! This couple is just one of the prizes in this year's Police Raffle. Other prizes include two years for breaking and entering, a crate of search warrants, a 'What's all this then?' T-shirt and a weekend for two with a skinhead of your own choice.
| CAPTION: 'STOP-PRESS'
Voice Over | And that's not all. Three fabulous new prizes have just been added, a four-month supply of interesting undergarments (picture), a fully motorized pig (picture c/o Mr Gilliam), and a hand-painted scene of Arabian splendour, complete with silly walk.
| Animation sketch leading to a booth in a quite expensive looking coffee shop, Italian style. Nigel is sitting there. Timmy William comes in. He has just the faintest passing resemblance to David Frost.
Timmy | Nigel! Wonderful to see you, super, super, super. Am I a teeny bit late?
Nigel | A bit, an hour.
Timmy | Oh, super! Only Snowdon's been re-touching my profile and we can't upset the lovely Snowdon, can we?
Nigel | Gosh, no.
| A man passes.
Timmy | (gets up and clasps his hands) ... David Bloggs ... the one and only ... super to see you. Who are you working for? Come and work for me, I'll call you tomorrow. (sits down) It's really lovely to have this little chat with you.
Nigel | Well, I...
Timmy | It is so nice to have this little talk about things. I heard a teeny rumourlette that you were married.
Nigel | Well, not quite, no. My wife's just died, actually.
Timmy | Oh dear. (sees another man passing) Brian! (extends his arm) We must get together again soon. See you. Bye. (to Nigel) Well, perhaps we could do a tribute to her on the show.
Nigel | Well, no. I...
Timmy | I'll get Peter, William, Arthur, Alex, Joan, Ted, Scott, Will, John and Ray to fix it up. It is so nice having this little chat.
Nigel | Well, actually Timmy, I'm glad to get you on your own...
| A reporter comes up to the table.
Timmy | You don't mind if Peter just sits in, do you?
Nigel | Well, actually...
Timmy | Only he's doing an article on me for the 'Mail'. He's such a lovely person.
Reporter | Hello.
Timmy | Peter, this is one of the nicest people in the world, Nigel Watt. (Peter scribbles it down) W-A-double T. That's right, yes.
Nigel | Well, actually, Timmy, the thing is, it's a bit private.
| A writer comes to the table.
Timmy | Oh, you don't mind if Peter just sits in, do you? Only Peter's writing a book on me. Peter, you know Tony from the 'Mail', don't you?
Peter | Yes, we met in the Turkish bath yesterday.
Timmy | Super, super. Did it come up well in the writing yesterday?
Peter | Great, great, great.
Timmy | You took out the tummy references? (makes fatness signs)
Peter | Yes, I did.
Timmy | Super, super, super. Just to fill you in, this is Nigel Watt and we are having a little heart-to-heart. H-E-A-R-T. Smashing. Do go on, Nigel.
| They both start writing.
Nigel | Well, well, the thing is, Timmy, um er...
| Timmy is smiling and posing. Nigel stops and looks. There is a photographer, hovering.
Timmy | Do carry on, it's the 'TV Times', only they syndicate these photographs to America. Would you mind if we just er... (grabs him by the hand and poses hearty friendship photo) Super, super. One over here, I think, Bob. A little smile, please, smashing, smashing. Feel free, Bob, to circulate, won't you. Do go on, this is most interesting.
Nigel | Well, the thing is, Timmy, I'm a bit embarrassed.
Waiter | (coming to table) Oh, Mr Willimas, it's so nice to see you. Will you sign this for my little daughter, please?
Timmy | Hello, Mario. Super, wonderful. (signs) Just two lovely coffees, please.
| Director comes in.
Director | Sorry, sorry, Timmy. Can we just go from where Mario comes in, we're getting bad sound, OK?
Timmy | It's German television. Isn't it exciting, Nigel? They're doing a prize-winning documentary on me.
| We see a film camera and the whole crew gathered round.
Clapper Boy | 'The Wonderful Mr Williams', scene 239, take 2.
Director | Action!
Timmy | (taking the cue, switches) Mario, how super to see you. How are the lovely family? Please give your little daughter this. (hands him a five pound note) Thank you. And just two lovely coffees, please.
Mario | Yes, sir.
Timmy | (to Nigel) Such a lovely waiter. Now, go on please, this is most interesting.
Nigel | Well ... er... as I was saying, Timmy, my wife's gone... gone. (close-up on him) I've got three children and I'm at my wits end. No job, no insurance, no money at all. I'm absolutely flat broke, I just don't know where to turn. I... I'm absolutely at the end of my tether. You're my only chance. Can you help me, please, Timmy?
| He looks up, Timmy isn't there. Timmy comes bounding back.
Timmy | Sorry, I was on the phone to America. It's been super having this lovely little chat. We must do this again more often. Er... will you get the coffees? I'm afraid I must dash, I'm an hour late for the Israeli Embassy. (there is a shot; Nigel slumps over the table, gun in his hand) Er... did you get that shot all right, sound?
Sound Man | (off screen) Yes, fine.
Timmy | It... it wasn't a bit too wicked, was it? I mean, it wasn't too cruel?
Tony and Peter | No, no, no. It was great.
Timmy | No, super... well, er... I think it shows I'm human, don't you?
Tony and Peter | Yes, great.
Timmy | Super, super. Well, the charabanc's here. Go on, everybody. Bye. (he waves)
| They all troop off after him. Theme music starts to come up, we pull back and see the camera set-up. Credits start to roll:
Voice Over | Timmy Williams' 'Coffee Time' was brought to you live from Woppi's in Holborn.
| Credits continue to roll: THEME SCRIPT BY (enormous letters) TIMMY WILLIAMS ENTIRELY WRITTEN BY (enormous letters) TIMMY WILLIAMS ADDITIONAL MATERIAL BY: (these go straight through very fast) PETER WRAY LEN ASHLEY GEOFFREY INGERSOLL GEORGE HERBERT HARRY LOWALL RALPH EMERSON HATTY STARR FRANK PICKSLEY JOHN STAMFORD SHELLEY BUNHEUR MALCOLM KERR JAMES BEACH ALAN BAILEY BRIAN FELDMAN STIRLING HARTLEY ADRIAN BEAMISH GUY WARING MARK TOMKINS SIDNEY SMITH RICHARD HOVEY EDMUND GOSSE JONATHAN ASHMORE BILL WRIGHT ARTHUR FULLER RICHARD SAVAGE MICHAEL WHITEMORE BUDGE RYAN CEDRIC HAZLETT TERRY JONES MICHAEL PALIN JOHN GAYNOR GEORGE COLEMAN SAMUEL SPURGEON THOMAS MASSINGER STEPHEN DAVIS WALTER CHAPMAN REGINALD MARWOOD DAVID GOSCHEN PETER SCHULMAN DENNIS FRANKEL DAVID ROBINSON PAUL RAYMOND JOHN WILLDER JOHNNY LYNN JOE SHAW SIMON SMITH MONTY PYTHON MICHAEL LAPIN SYDNEY LOTTERBY IAN MATHERSON HUMPHREY BARCLAY BURT ANCASTER KIRK OUGLAS KEN SMITH GEOFFREY HUGHES BRIAN FITZJONES MICHAEL GOWERS JOHN PENNYCATE PETER BAKER NEIL SHAND Fade out. Fade in on ordinary interview set. Interviewer sitting with man with large semitic polystyrene nose.
Interviewer | Good evening. I have with me in the studio tonight one of the country's leading skin specialists - Raymond Luxury Yacht.
Raymond | That's not my name.
Interviewer | I'm sorry - Raymond Luxury Yach-t.
Raymond | No, no, no - it's spelt Raymond Luxury Yach-t, but it's pronounced 'Throatwobbler Mangrove'.
Interviewer | You're a very silly man and I'm not going to interview you.
Raymond | Ah, anti-semitism!
Interviewer | Not at all. It's not even a proper nose. (takes it off) It's polystyrene.
Raymond | Give me my nose back.
Interviewer | You can collect it at reception. Now go away.
Raymond | I want to be on the television.
Interviewer | Well you can't.
| Animation sketch. The cut to a large sign saying 'Registry Office ', 'Marriages' etc. A man is talking to the registrar.
First Man | Er, excuse me, I want to get married.
Registrar | I'm afraid I'm already married, sir.
First Man | Er, no, no. I just want to get married.
Registrar | I could get a divorce, I suppose, but it'll be a bit of a wrench.
First Man | Er, no, no. That wouldn't be necessary because...
Registrar | You see, would you come to my place or should I have to come to yours, because I've just got a big mortgage.
First Man | No, no, I want to get married here.
Registrar | Oh dear. I had my heart set on a church wedding.
First Man | Look, I just want you to marry me... to...
Registrar | I want to marry you too sir, but it's not as simple as that. You sure you want to get married?
First Man | Yes. I want to get married very quickly.
Registrar | Suits me, sir. Suits me.
First Man | I don't want to marry you!
Registrar | There is such a thing as breach of promise, sir.
First Man | Look, I just want you to act as registrar and marry me.
Registrar | I will marry you sir, but please make up your mind. Please don't trifle with my affections.
First Man | I'm sorry, but...
Registrar | That's all right, sir. I forgive you. Lovers' tiff. But you're not the first person to ask me today. I've turned down several people already.
First Man | Look, I'm already engaged.
Registrar | (agreeing and thinking) Yes, and I'm already married. Still we'll get round it.
Second Man | (entering) Good morning. I want to get married.
Registrar | I'm afraid I'm already marrying this gentleman, sir.
Second Man | Well, can I get married after him?
Registrar | Well, divorce isn't as quick as that, sir. Still, if you're keen.
Third Man | (entering) I want to get married, please.
Registrar | Heavens, it's my lucky day, isn't it. All right, but you'll have to wait until I've married these two, sir.
Third Man | What, those two getting married... Nigel What are you doing marrying him?
Registrar | He's marrying me first, sir.
Third Man | He's engaged to me.
Fourth Man | (big and butch) Come on, Henry.
Registrar | Blimey, the wife.
Second Man | Will you marry me?
Fourth Man | I'm already married.
| Cut to a photo of all five of them standing happily outside a house.
Voice Over | Well, things turned out all right in the end, but you musn't ask how 'cos it's naughty. They're all married and living quite well in a council estate near Dulwich.
| ANIMATION: 'The Spot' CAPTION: 'ELECTION NIGHT SPECIAL' Cut to linkman sitting at desk.
Linkman | (very excited): Hello and welcome to 'Election Night Special'. There's great excitement here as we should be getting the first results through any minute now. We don't know where it'll be from...it might be Leicester or from Luton. The polling's been quite heavy in both areas... oh, wait a moment...I'm just getting...I'm just getting a loud buzzing noise in my left ear. Excuse me a moment. (he bangs ear and knocks a large bee out) Uuggh! (cheering from crowd). Anyway, let's go straight over to James Gilbert at Leicester.
| Shot of returning officer in front of a group consisting half of grey-suited, half of silly-dressed candidates and agents. The silly ones are in extraordinary hats, false noses etc.
Voice Over | Well it's a straight fight here at Leicester...On the left of the Returning Officer (camera shoes grey-suited man) you can see Arthur Smith, the Sensible candidate and his agent, (camera pans to silly people) and on the other side is the silly candidate Jethro Walrustitty with his agent and his wife.
Officer | Here is the result for Leicester. Arthur J. Smith...
Voice Over | Sensible Party
Officer | 30,612...Jethro Q. Walrustitty...
Voice Over | Silly Party
Officer | 32,108.
| Cheering from the crowd. Cut back to studio.
Linkman | (even more excited) Well, there's the first result and the Silly Party has held Leicester. What do you make of that, Norman?
| Cut to Norman. He is very excited.
Norman | Well, this is largely as I predicted, except that the Silly Party won. I think this is largely due to the number of votes cast. Gerald?
| Cut to Gerald standing by the 'swingometer' - a pivoted pointer on a wall chart.
Gerald | Well there's a swing here to the Silly Party...but how big a swing I'm not going to tell you.
| Cut to George also standing by a swingometer.
George | Well, if I may...I think the interesting thing here is the big swing to the Silly Party and of course the very large swing back to the Sensible Party...and a tendency to wobble up and down in the middle because the screw's loose.
| Cut to Alphonse.
Alphonse | No, I'm afraid I can't think of anything.
| Cut to Eric.
Eric | I can't add anything to that. Colin?
| Cut to Colin.
Colin (Ian Davidson) | Can I butt in at this point and say this is in fact the very first time I've appeared on television.
| Cut to linkman.
Linkman | No, no we haven't time, because we're just going straight over to Luton.
| Cut to Luton Town Hall. There are sensible, silly and slightly silly candidates.
Voice Over | Here at Luton it's a three-cornered fight between Alan Jones - Sensible Party, in the middle, Tarquin Fin- tim- lim- bim- whin- bim- lim- bus- stop- F'tang- F'tang- Olè- Biscuitbarrel - Silly Party, and Kevin Phillips-Bong, the Slightly Silly candidate.
Officer | Alan Jones...
Voice Over | On the left, Sensible Party
Officer | 9,112... Kevin Phillips-Bong...
Voice Over | On the right, Slightly Silly.
Officer | Nought...Tarquin Fin- tim- lin- bin- whin- bim- lin- bus- stop- F'tang- F'tang- Olé- Biscuitbarrel...
Voice Over | Silly.
Officer | 12,441.
Voice Over | And so the Silly Party has taken Luton.
Linkman | A gain for the Silly Party at Luton. The first gain of the election, Norman?
Norman | Well this is a highly significant result. Luton, normally a very sensible constituency with a high proportion of people who aren't a bit silly, has gone completely ga-ga.
Linkman | Do we have the swing at Luton?
Gerald | Well, I've worked out the swing, but it's a secret.
Linkman | Er, well, ah, there...there isn't the swing, how about a swong?
Norman | Well, I've got the swong here in this box and it's looking fine. I can see through the breathing holes that it's eating up peanuts at the rate of knots.
Linkman | And how about the swang?
Alphonse | Well, it's 29% up over six hunded feet but it's a little bit soft around the edges about...
Linkman | What do you make of the nylon dot cardigan and plastic mule rest?
Voice | (off) There's no such thing.
Linkman | Thank you, Spike.
Norman | Can I just come in here and say that the swong has choked itself to death.
George | Well, the election's really beginning to hot up now.
Eric | I can't add anything to that.
Colin | Can I just add at this point that this is in fact the second time I've ever been on television?
Linkman | I'm sorry, Sasha, we're just about to get another result.
| A large number of candidates in Harpenden Town Hall.
Voice Over | Hello, from Harpenden. This is a key seat because in addition to the official Silly candidate there is an independent Very Silly candidate (in large cube of polystyrene with only legs sticking out) who may split the silly vote.
Officer | Mrs Elsie Zzzzzzzzzzzzzzz... (obvious man in drag with enormous joke breasts)
Voice Over | Silly.
Officer | 26,317... James Walker...
Voice Over | Sensible.
Officer | 26,318.
Voice Over | That was close.
Officer | Malcolm Peter Brian Telescope Adrian Umbrella Stand Jasper Wednesday (pops mouth twice) Stoatgobbler John Raw Vegetable (sound effect of horse whinnying) Arthur Norman Michael (blows squeker) Featherstone Smith (blows whistle) Northgot Edwards Harris (fires pistol, which goes 'whoop') Mason (chuff-chuff-chuff) Frampton Jones Fruitbat Gilbert (sings) 'We'll keep a welcome in the' (three shots, stops singing) Williams If I Could Walk That Way Jenkin (squeker) Tiger-draws Pratt Thompson (sings) 'Raindrops Keep Falling On My Head' Darcy Carter (horn) Pussycat 'Don't Sleep In The Subway' Barton Mannering (hoot, 'whoop') Smith.
Voice Over | Very Silly.
Officer | Two.
Voice Over | Well there you have it. A Sensible gain at Driffield.
| Back to the studio.
Linkman | Norman
Norman | Well, I've just heard from Luton that my auntie's ill, er, possibly, possibly gastro-enteritis - Gerald.
Gerald | Er, well, if this were repeated over the whole country it's probably be very messy. Colin.
Colin | Can I just butt in and say here that it's probably the last time I shall ever appear on television.
Linkman | No I'm afraid you can't, we haven't got time. Just to bring you up to date with a few results, er, that you may have missed. Engelbert Humperdinck has taken Barrow-in-Furness, that's a gain from Ann Haydon-Jones and her husband Pip. Arthur Negus has held Bristols. That's not a result, that's a bit of gossip. Er...Mary Whitehouse has just taken umbrage. Could it be a bit of trouble there. And apparently Wales is not swinging at all. No surprise there. And...Monty Python has held the credits.
| Roll credits. Lots of activity behind from the experts. SUPERIMPOSED FLASHING CAPTION: 'NO CHANGE'